==> codebuild-1.60.0-sources.jar: software/amazon/awscdk/services/codebuild/SourceConfig.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * The type returned from {@link ISource#bind}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:32.930Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.SourceConfig")
@software.amazon.jsii.Jsii.Proxy(SourceConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SourceConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty getSourceProperty();

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty getBuildTriggers() {
        return null;
    }

    /**
     * `AWS::CodeBuild::Project.SourceVersion`.
     * <p>
     * Default: the latest version
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codebuild-project.html#cfn-codebuild-project-sourceversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourceVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SourceConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SourceConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SourceConfig> {
        private software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty sourceProperty;
        private software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty buildTriggers;
        private java.lang.String sourceVersion;

        /**
         * Sets the value of {@link SourceConfig#getSourceProperty}
         * @param sourceProperty the value to be set. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceProperty(software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty sourceProperty) {
            this.sourceProperty = sourceProperty;
            return this;
        }

        /**
         * Sets the value of {@link SourceConfig#getBuildTriggers}
         * @param buildTriggers the value to be set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder buildTriggers(software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty buildTriggers) {
            this.buildTriggers = buildTriggers;
            return this;
        }

        /**
         * Sets the value of {@link SourceConfig#getSourceVersion}
         * @param sourceVersion `AWS::CodeBuild::Project.SourceVersion`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceVersion(java.lang.String sourceVersion) {
            this.sourceVersion = sourceVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SourceConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SourceConfig build() {
            return new Jsii$Proxy(sourceProperty, buildTriggers, sourceVersion);
        }
    }

    /**
     * An implementation for {@link SourceConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SourceConfig {
        private final software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty sourceProperty;
        private final software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty buildTriggers;
        private final java.lang.String sourceVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.sourceProperty = this.jsiiGet("sourceProperty", software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty.class);
            this.buildTriggers = this.jsiiGet("buildTriggers", software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty.class);
            this.sourceVersion = this.jsiiGet("sourceVersion", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty sourceProperty, final software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty buildTriggers, final java.lang.String sourceVersion) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.sourceProperty = java.util.Objects.requireNonNull(sourceProperty, "sourceProperty is required");
            this.buildTriggers = buildTriggers;
            this.sourceVersion = sourceVersion;
        }

        @Override
        public software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty getSourceProperty() {
            return this.sourceProperty;
        }

        @Override
        public software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty getBuildTriggers() {
            return this.buildTriggers;
        }

        @Override
        public java.lang.String getSourceVersion() {
            return this.sourceVersion;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("sourceProperty", om.valueToTree(this.getSourceProperty()));
            if (this.getBuildTriggers() != null) {
                data.set("buildTriggers", om.valueToTree(this.getBuildTriggers()));
            }
            if (this.getSourceVersion() != null) {
                data.set("sourceVersion", om.valueToTree(this.getSourceVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codebuild.SourceConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SourceConfig.Jsii$Proxy that = (SourceConfig.Jsii$Proxy) o;

            if (!sourceProperty.equals(that.sourceProperty)) return false;
            if (this.buildTriggers != null ? !this.buildTriggers.equals(that.buildTriggers) : that.buildTriggers != null) return false;
            return this.sourceVersion != null ? this.sourceVersion.equals(that.sourceVersion) : that.sourceVersion == null;
        }

        @Override
        public int hashCode() {
            int result = this.sourceProperty.hashCode();
            result = 31 * result + (this.buildTriggers != null ? this.buildTriggers.hashCode() : 0);
            result = 31 * result + (this.sourceVersion != null ? this.sourceVersion.hashCode() : 0);
            return result;
        }
    }
}

==> codebuild-1.93.0-sources.jar: software/amazon/awscdk/services/codebuild/SourceConfig.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * The type returned from {@link ISource#bind}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:51.405Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.SourceConfig")
@software.amazon.jsii.Jsii.Proxy(SourceConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SourceConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty getSourceProperty();

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty getBuildTriggers() {
        return null;
    }

    /**
     * `AWS::CodeBuild::Project.SourceVersion`.
     * <p>
     * Default: the latest version
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codebuild-project.html#cfn-codebuild-project-sourceversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourceVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SourceConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SourceConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SourceConfig> {
        private software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty sourceProperty;
        private software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty buildTriggers;
        private java.lang.String sourceVersion;

        /**
         * Sets the value of {@link SourceConfig#getSourceProperty}
         * @param sourceProperty the value to be set. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceProperty(software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty sourceProperty) {
            this.sourceProperty = sourceProperty;
            return this;
        }

        /**
         * Sets the value of {@link SourceConfig#getBuildTriggers}
         * @param buildTriggers the value to be set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder buildTriggers(software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty buildTriggers) {
            this.buildTriggers = buildTriggers;
            return this;
        }

        /**
         * Sets the value of {@link SourceConfig#getSourceVersion}
         * @param sourceVersion `AWS::CodeBuild::Project.SourceVersion`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceVersion(java.lang.String sourceVersion) {
            this.sourceVersion = sourceVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SourceConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SourceConfig build() {
            return new Jsii$Proxy(sourceProperty, buildTriggers, sourceVersion);
        }
    }

    /**
     * An implementation for {@link SourceConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SourceConfig {
        private final software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty sourceProperty;
        private final software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty buildTriggers;
        private final java.lang.String sourceVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.sourceProperty = software.amazon.jsii.Kernel.get(this, "sourceProperty", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty.class));
            this.buildTriggers = software.amazon.jsii.Kernel.get(this, "buildTriggers", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty.class));
            this.sourceVersion = software.amazon.jsii.Kernel.get(this, "sourceVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty sourceProperty, final software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty buildTriggers, final java.lang.String sourceVersion) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.sourceProperty = java.util.Objects.requireNonNull(sourceProperty, "sourceProperty is required");
            this.buildTriggers = buildTriggers;
            this.sourceVersion = sourceVersion;
        }

        @Override
        public final software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty getSourceProperty() {
            return this.sourceProperty;
        }

        @Override
        public final software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty getBuildTriggers() {
            return this.buildTriggers;
        }

        @Override
        public final java.lang.String getSourceVersion() {
            return this.sourceVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("sourceProperty", om.valueToTree(this.getSourceProperty()));
            if (this.getBuildTriggers() != null) {
                data.set("buildTriggers", om.valueToTree(this.getBuildTriggers()));
            }
            if (this.getSourceVersion() != null) {
                data.set("sourceVersion", om.valueToTree(this.getSourceVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codebuild.SourceConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SourceConfig.Jsii$Proxy that = (SourceConfig.Jsii$Proxy) o;

            if (!sourceProperty.equals(that.sourceProperty)) return false;
            if (this.buildTriggers != null ? !this.buildTriggers.equals(that.buildTriggers) : that.buildTriggers != null) return false;
            return this.sourceVersion != null ? this.sourceVersion.equals(that.sourceVersion) : that.sourceVersion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.sourceProperty.hashCode();
            result = 31 * result + (this.buildTriggers != null ? this.buildTriggers.hashCode() : 0);
            result = 31 * result + (this.sourceVersion != null ? this.sourceVersion.hashCode() : 0);
            return result;
        }
    }
}
